@@ -1,7 +1,18 @@
+"""This module implements all state handling during uploads and downloads, the
+main interface to which being the TftpContext base class and the TftpState
+base class. 
+
+The concept is simple. Each context object represents a single upload or
+download, and the state object in the context object represents the current
+state of that transfer. The state object has a handle() method that expects
+the next packet in the transfer, and returns a state object until the transfer
+is complete, at which point it returns None. That is, unless there is a fatal
+error, in which case a TftpException is returned instead."""
+
 from TftpShared import *
 from TftpPacketTypes import *
 from TftpPacketFactory import *
-import socket, time, os
+import socket, time, os, sys
 
 ###############################################################################
 # Utility classes
@@ -30,6 +41,8 @@ class TftpMetrics(object):
     def compute(self):
         # Compute transfer time
         self.duration = self.end_time - self.start_time
+        if self.duration == 0:
+            self.duration = 1
         log.debug("TftpMetrics.compute: duration is %s" % self.duration)
         self.bps = (self.bytes * 8.0) / self.duration
         self.kbps = self.bps / 1024.0
@@ -221,7 +234,8 @@ class TftpContextServer(TftpContext):
         self.metrics.compute()
 
 class TftpContextClientUpload(TftpContext):
-    """The upload context for the client during an upload."""
+    """The upload context for the client during an upload.
+    Note: If input is a hyphen, then we will use stdin."""
     def __init__(self,
                  host,
                  port,
@@ -237,7 +251,10 @@ class TftpContextClientUpload(TftpContext):
         self.file_to_transfer = filename
         self.options = options
         self.packethook = packethook
-        self.fileobj = open(input, "rb")
+        if input == '-':
+            self.fileobj = sys.stdin
+        else:
+            self.fileobj = open(input, "rb")
 
         log.debug("TftpContextClientUpload.__init__()")
         log.debug("file_to_transfer = %s, options = %s" %
@@ -276,7 +293,8 @@ class TftpContextClientUpload(TftpContext):
         self.metrics.compute()
 
 class TftpContextClientDownload(TftpContext):
-    """The download context for the client during a download."""
+    """The download context for the client during a download.
+    Note: If output is a hyphen, then the output will be sent to stdout."""
     def __init__(self,
                  host,
                  port,
@@ -295,7 +313,11 @@ class TftpContextClientDownload(TftpContext):
         self.packethook = packethook
         # FIXME - need to support alternate return formats than files?
         # File-like objects would be ideal, ala duck-typing.
-        self.fileobj = open(output, "wb")
+        # If the filename is -, then use stdout
+        if output == '-':
+            self.fileobj = sys.stdout
+        else:
+            self.fileobj = open(output, "wb")
 
         log.debug("TftpContextClientDownload.__init__()")
         log.debug("file_to_transfer = %s, options = %s" %
@@ -406,13 +428,14 @@ class TftpState(object):
         if not self.context.tidport:
             self.context.tidport = rport
             log.info("Setting tidport to %s" % rport)
-        if not options:
-            log.debug("Setting default options, blksize")
-            # FIXME: put default options elsewhere
-            self.context.options = { 'blksize': DEF_BLKSIZE }
-        else:
+
+        log.debug("Setting default options, blksize")
+        self.context.options = { 'blksize': DEF_BLKSIZE }
+
+        if options:
             log.debug("Options requested: %s" % options)
-            self.context.options = self.returnSupportedOptions(options)
+            supported_options = self.returnSupportedOptions(options)
+            self.context.options.update(supported_options)
             sendoack = True
 
         # FIXME - only octet mode is supported at this time.
@@ -741,7 +764,7 @@ class TftpStateSentWRQ(TftpState):
             if pkt.blocknumber == 0:
                 log.debug("Ack blocknumber is zero as expected")
                 log.debug("Sending first DAT packet")
-                self.pending_complete = self.context.sendDAT()
+                self.context.pending_complete = self.sendDAT()
                 log.debug("Changing state to TftpStateExpectACK")
                 return TftpStateExpectACK(self.context)
             else:
